==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QStyleHintReturn_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturn(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturn")
    QStyleHintReturn *_ptr = reinterpret_cast<QStyleHintReturn *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    Q_UNUSED(__java_arguments)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    jint version0 = __java_arguments[0].i;
    Q_UNUSED(version0)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn(static_cast<int>(version0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    jint version0 = __java_arguments[0].i;
    Q_UNUSED(version0)
    jint type1 = __java_arguments[1].i;
    Q_UNUSED(type1)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn(static_cast<int>(version0), static_cast<int>(type1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QStyleHintReturn
void __qt_destruct_QStyleHintReturn(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturn")
    reinterpret_cast<QStyleHintReturn*>(ptr)->~QStyleHintReturn();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleHintReturn::QStyleHintReturn(int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_initialize_1native__Lio_qt_widgets_QStyleHintReturn_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint version0,
 jint type1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturn::QStyleHintReturn(int,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].i = version0;
        arguments[1].i = type1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturn_2, sizeof(QStyleHintReturn), typeid(QStyleHintReturn), false, &deleter_QStyleHintReturn, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_setType_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->type = static_cast<int>(type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->type;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_setVersion_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint version0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->version = static_cast<int>(version0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_version_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->version;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleHintReturn(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleHintReturn>("QStyleHintReturn", "io/qt/widgets/QStyleHintReturn");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleHintReturn, {
        ConstructorInfo(&__qt_construct_QStyleHintReturn_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleHintReturn_1, "I")
       ,ConstructorInfo(&__qt_construct_QStyleHintReturn_2, "II")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturn);
    registerMetaType<QStyleHintReturn>("QStyleHintReturn");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QStyleHintReturn::HintReturnType>("QStyleHintReturn::HintReturnType", "io/qt/widgets/QStyleHintReturn$HintReturnType");
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStyleHintReturn_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturn(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturn")
    QStyleHintReturn *_ptr = reinterpret_cast<QStyleHintReturn *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturn(QStyleHintReturn)
void __qt_construct_QStyleHintReturn_cref_QStyleHintReturn(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(QStyleHintReturn)")
    jobject other0 = __java_arguments[0].l;
    const QStyleHintReturn& __qt_other0 = qtjambi_cast<const QStyleHintReturn& >(__jni_env, other0);
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStyleHintReturn::QStyleHintReturn(QStyleHintReturn)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_initialize_1native__Lio_qt_widgets_QStyleHintReturn_2Lio_qt_widgets_QStyleHintReturn_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturn::QStyleHintReturn(QStyleHintReturn)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturn_cref_QStyleHintReturn, sizeof(QStyleHintReturn), typeid(QStyleHintReturn), false, &deleter_QStyleHintReturn, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    Q_UNUSED(__java_arguments)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    jint version0 = __java_arguments[0].i;
    Q_UNUSED(version0)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn(static_cast<int>(version0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleHintReturn(int,int)
void __qt_construct_QStyleHintReturn_int_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturn(int,int)")
    jint version0 = __java_arguments[0].i;
    Q_UNUSED(version0)
    jint type1 = __java_arguments[1].i;
    Q_UNUSED(type1)
    QStyleHintReturn *__qt_this = new(__qtjambi_ptr) QStyleHintReturn(static_cast<int>(version0), static_cast<int>(type1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleHintReturn::QStyleHintReturn(int,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_initialize_1native__Lio_qt_widgets_QStyleHintReturn_2II)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint version0,
 jint type1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturn::QStyleHintReturn(int,int)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].i = version0;
        arguments[1].i = type1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturn_int_int, sizeof(QStyleHintReturn), typeid(QStyleHintReturn), false, &deleter_QStyleHintReturn, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleHintReturn
void __qt_destruct_QStyleHintReturn(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturn")
    reinterpret_cast<QStyleHintReturn*>(ptr)->~QStyleHintReturn();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_setType_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->type = static_cast<int>(type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->type;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_setVersion_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint version0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->version = static_cast<int>(version0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_version_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->version;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturn_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleHintReturn *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturn>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleHintReturn(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleHintReturn>("QStyleHintReturn", "io/qt/widgets/QStyleHintReturn");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleHintReturn, {
        ConstructorInfo(&__qt_construct_QStyleHintReturn_cref_QStyleHintReturn, "Lio/qt/widgets/QStyleHintReturn;")
       ,ConstructorInfo(&__qt_construct_QStyleHintReturn, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleHintReturn_int, "I")
       ,ConstructorInfo(&__qt_construct_QStyleHintReturn_int_int, "II")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturn);
    registerMetaType<QStyleHintReturn>("QStyleHintReturn");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QStyleHintReturn::HintReturnType>("QStyleHintReturn::HintReturnType", "io/qt/widgets/QStyleHintReturn$HintReturnType");
// END: enums and flags
}
